==> babel-preset-proposal-typescript-1.4.6.tgz: package/lib/esm.js <==
import syntaxDecorators from '@babel/plugin-syntax-decorators';
import syntaxDynamicImport from '@babel/plugin-syntax-dynamic-import';
import syntaxTypeScript from '@babel/plugin-syntax-typescript';
import proposalClassProperties from '@babel/plugin-proposal-class-properties';
import proposalDoExpressions from '@babel/plugin-proposal-do-expressions';
import proposalFunctionBind from '@babel/plugin-proposal-function-bind';
import proposalFunctionSent from '@babel/plugin-proposal-function-sent';
import proposalJsonStrings from '@babel/plugin-proposal-json-strings';
import proposalLogicalAssignmentOperators from '@babel/plugin-proposal-logical-assignment-operators';
import proposalNullishCoalescingOperator from '@babel/plugin-proposal-nullish-coalescing-operator';
import proposalOptionalChaining from '@babel/plugin-proposal-optional-chaining';
import proposalPartialApplication from '@babel/plugin-proposal-partial-application';
import proposalPipelineOperator from '@babel/plugin-proposal-pipeline-operator';
import proposalPrivateMethods from '@babel/plugin-proposal-private-methods';
import proposalThrowExpression from '@babel/plugin-proposal-throw-expressions';
import { declare } from '@babel/helper-plugin-utils';

var syntaxV8intrinsic = declare(function (api) {
    api.assertVersion(7);
    return {
        name: 'v8intrinsic',
        manipulateOptions: function (_opts, parserOpts) {
            parserOpts.plugins.push('v8intrinsic');
        },
    };
});

var index = declare(function (api, _a) {
    var _b = _a.classLoose, classLoose = _b === void 0 ? true : _b, decoratorsBeforeExport = _a.decoratorsBeforeExport, _c = _a.decoratorsLegacy, decoratorsLegacy = _c === void 0 ? true : _c, isTSX = _a.isTSX, _d = _a.pipelineOperator, pipelineOperator = _d === void 0 ? 'minimal' : _d;
    api.assertVersion(7);
    return {
        plugins: [
            [
                syntaxDecorators,
                {
                    decoratorsBeforeExport: decoratorsBeforeExport,
                    legacy: decoratorsLegacy,
                },
            ],
            syntaxDynamicImport,
            [
                syntaxTypeScript,
                {
                    isTSX: isTSX,
                },
            ],
            syntaxV8intrinsic,
            [
                proposalClassProperties,
                {
                    loose: classLoose,
                },
            ],
            proposalDoExpressions,
            proposalFunctionBind,
            proposalFunctionSent,
            proposalJsonStrings,
            proposalLogicalAssignmentOperators,
            proposalNullishCoalescingOperator,
            proposalOptionalChaining,
            proposalPartialApplication,
            [
                proposalPipelineOperator,
                {
                    proposal: pipelineOperator,
                },
            ],
            [
                proposalPrivateMethods,
                {
                    loose: classLoose,
                },
            ],
            proposalThrowExpression,
        ],
        // no need to override if it has been enabled
        overrides: isTSX
            ? undefined
            : [
                {
                    test: /\.[jt]sx$/,
                    plugins: [
                        [
                            syntaxTypeScript,
                            {
                                isTSX: true,
                            },
                        ],
                    ],
                },
            ],
    };
});

export default index;

==> babel-preset-proposal-typescript-2.0.1.tgz: package/lib/esm.js <==
import { declare } from '@babel/helper-plugin-utils';
import proposalClassProperties from '@babel/plugin-proposal-class-properties';
import proposalClassStaticBlock from '@babel/plugin-proposal-class-static-block';
import proposalDoExpressions from '@babel/plugin-proposal-do-expressions';
import proposalFunctionBind from '@babel/plugin-proposal-function-bind';
import proposalFunctionSent from '@babel/plugin-proposal-function-sent';
import proposalJsonStrings from '@babel/plugin-proposal-json-strings';
import proposalOptionalChaining from '@babel/plugin-proposal-optional-chaining';
import proposalPartialApplication from '@babel/plugin-proposal-partial-application';
import proposalPipelineOperator from '@babel/plugin-proposal-pipeline-operator';
import proposalPrivateMethods from '@babel/plugin-proposal-private-methods';
import proposalPrivatePropertyInObject from '@babel/plugin-proposal-private-property-in-object';
import proposalThrowExpression from '@babel/plugin-proposal-throw-expressions';
import syntaxDecorators from '@babel/plugin-syntax-decorators';
import syntaxDynamicImport from '@babel/plugin-syntax-dynamic-import';
import syntaxTypeScript from '@babel/plugin-syntax-typescript';

var syntaxV8intrinsic = declare(function (api) {
    api.assertVersion(7);
    return {
        name: 'v8intrinsic',
        manipulateOptions: function (_opts, parserOpts) {
            parserOpts.plugins.push('v8intrinsic');
        },
    };
});

var index = declare(function (api, _a) {
    var _b = _a.classLoose, classLoose = _b === void 0 ? true : _b, decoratorsBeforeExport = _a.decoratorsBeforeExport, _c = _a.decoratorsLegacy, decoratorsLegacy = _c === void 0 ? true : _c, isTSX = _a.isTSX, _d = _a.pipelineOperator, pipelineOperator = _d === void 0 ? 'minimal' : _d;
    api.assertVersion(7);
    return {
        plugins: [
            [
                syntaxDecorators,
                {
                    decoratorsBeforeExport: decoratorsBeforeExport,
                    legacy: decoratorsLegacy,
                },
            ],
            syntaxDynamicImport,
            [
                syntaxTypeScript,
                {
                    isTSX: isTSX,
                },
            ],
            syntaxV8intrinsic,
            [
                proposalClassStaticBlock,
                {
                    loose: classLoose,
                },
            ],
            [
                proposalClassProperties,
                {
                    loose: classLoose,
                },
            ],
            proposalDoExpressions,
            proposalFunctionBind,
            proposalFunctionSent,
            proposalJsonStrings,
            proposalOptionalChaining,
            proposalPartialApplication,
            [
                proposalPipelineOperator,
                {
                    proposal: pipelineOperator,
                },
            ],
            [
                proposalPrivateMethods,
                {
                    loose: classLoose,
                },
            ],
            [
                proposalPrivatePropertyInObject,
                {
                    loose: classLoose,
                },
            ],
            proposalThrowExpression,
        ],
        // no need to override if it has been enabled
        overrides: isTSX
            ? undefined
            : [
                {
                    test: /\.[jt]sx$/,
                    plugins: [
                        [
                            syntaxTypeScript,
                            {
                                isTSX: true,
                            },
                        ],
                    ],
                },
            ],
    };
});

export default index;
